@@ -10,7 +10,7 @@
  *
  * Licensed under the GNU GPL v2.  See COPYING.
  *
- * (C) Copyright 2004 Novell, Inc.
+ * (C) Copyright 2005 Novell, Inc.
  */
 
 #include "config.h"
@@ -228,8 +228,9 @@ gvm_ask_autorun (const char *path)
 					GTK_BUTTONS_NONE,
 					_("Run command from inserted media?"));
 	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (askme),
-						  "%s", _("Do you want to run "
-						  "the file \"%s?\""));
+						  "%s", _("The file \"%s\" on "
+						  "the inserted media is an "
+						  "auto-run file."));
 	gtk_dialog_add_buttons (GTK_DIALOG (askme),
 				GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT,
 				_("_Run Command"), GTK_RESPONSE_ACCEPT,
@@ -319,8 +320,8 @@ gvm_check_photos (const char *udi, const char *device, const char *mount_point)
 		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (askme),
 				"%s",
 				_("There are photos on the inserted media. "
-				  "Would you like to import these photographs "
-				  "into your album?"));
+				  "Would you like to import these photos into "
+				  "your photo album?"));
 
 		gtk_dialog_add_buttons (GTK_DIALOG (askme),
 					GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
@@ -367,8 +368,8 @@ gvm_check_camera (const char *udi)
 		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (askme),
 				"%s",
 				_("There are photos on the plugged-in camera. "
-				  "Would you like to import these "
-				  "photographss into your album?"));
+				  "Would you like to import these photos "
+				  "into your photo album?"));
 		gtk_dialog_add_buttons (GTK_DIALOG (askme),
 					GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 					_("_Import Photos"), IMPORT,
@@ -967,14 +968,14 @@ static void mount_all (LibHalContext *ctx)
 	int i;
 	int num_volumes;
 	char **volumes;
-	char *udi;
-	char *device_file;
 
 	if (!config.automount_media)
 		return;
 
 	volumes = hal_find_device_by_capability (ctx, "volume", &num_volumes);
 	for (i = 0; i < num_volumes; i++) {
+		char *device_file, *udi;
+
 		udi = volumes [i];
 
 		/* don't attempt to mount already mounted volumes */
@@ -984,23 +985,26 @@ static void mount_all (LibHalContext *ctx)
 						  "volume.is_mounted"))
 			continue;
 
-		/* only mount if the block device got a sensible filesystem */
-		if (!hal_device_property_exists (ctx, udi, 
-						"volume.fsusage") ||
-		    strcmp (hal_device_get_property_string (ctx, udi, 
-							    "volume.fsusage"), 
-			    "filesystem") != 0)
+		/* only mount if the block device has a sensible filesystem */
+		if (!hal_device_property_exists (ctx, udi, "volume.fsusage"))
 			continue;
+		else {
+			char *fsusage;
+			fsusage = hal_device_get_property_string (ctx, udi,
+					"volume.fsusage");
+			if (strcmp (fsusage, "filesystem") != 0) {
+				hal_free_string (fsusage);
+				continue;
+			}
+			hal_free_string (fsusage);
+		}
 
 		device_file = hal_device_get_property_string (ctx, udi,
 							      "block.device");
 
 		if (device_file != NULL ) {
-
 			dbg ("mount_all: mounting %s\n", device_file);
-
 			gvm_device_mount (device_file);
-
 			hal_free_string (device_file);
 		} else
 			warn ("no device_file for udi=%s\n", udi);
